HealthReport class

Integrity and maintenance signals returned by a diagnostics provider.

Constructors

HealthReport({required double globalScore, required bool crcValid, required bool indexConsistent, required bool recoveryClean, required bool noPendingCompaction})
Creates a health report for an inspected database.

Properties

crcValid bool
final
globalScore double
final
hashCode int
The hash code for this object.
no setterinherited
indexConsistent bool
final
noPendingCompaction bool
final
protocolVersion int
final
recoveryClean bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this health report to a protocol JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited