InspectionValue class
One raw storage record with optional decoded content for inspection tools.
Constructors
- InspectionValue({required String key, required String serializerName, Object? decodedValue, String? decodeError, required int sizeBytes, required String rawHex})
- Creates an inspectable storage value.
-
InspectionValue.fromJson(Map<
String, dynamic> json) -
Restores an inspected value from its protocol JSON representation.
factory
Properties
- decodedValue → Object?
-
final
- decodeError → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
final
- protocolVersion → int
-
final
- rawHex → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serializerName → String
-
final
- sizeBytes → int
-
final
- typeName → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this value to a protocol JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited