StorageInfo class
Describes the storage engine, format, and physical database footprint.
Constructors
-
StorageInfo({required int engineVersion, required int storageFormatVersion, required String backendType, required String appId, required String databaseId, required int logicalSizeBytes, required int physicalSizeBytes, required int reclaimableSpaceBytes, required double compactionRatio, required double fragmentation, required int largestBatchSize, required int largestValueSize, required List<
String> featureFlags}) - Creates storage metadata for one inspected database.
Properties
- appId → String
-
final
- backendType → String
-
final
- compactionRatio → double
-
final
- databaseId → String
-
final
- engineVersion → int
-
final
-
featureFlags
→ List<
String> -
final
- fragmentation → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- largestBatchSize → int
-
final
- largestValueSize → int
-
final
- logicalSizeBytes → int
-
final
- physicalSizeBytes → int
-
final
- protocolVersion → int
-
final
- reclaimableSpaceBytes → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageFormatVersion → int
-
final
- typeName → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this storage metadata to a protocol JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited